* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
TITLE; ODS TRACE OFF; ODS LISTING;

***********************************************************************************;
*******   MACRO PROGRAMS TO AUTOMATE CALCULATIONS FOR CHAPTER 2 EXAMPLE     *******;
*******               NOTHING IN HERE NEEDS TO BE CHANGED                   *******;
***********************************************************************************;

* To use ModelR2 macro for chapter 2 cross-sectional models;
* CovFewer =    name of covparms table for baseline empty model;
* CovFewer =    name of covparms table for nested model;
* CovMore =     name of covparms table for comparison model;
%MACRO ModelR2(CovBase=,CovFewer=,CovMore=);
DATA &CovBase.;  LENGTH Name $30.; SET &CovBase.;  Name="&CovBase." ;  
     CALL SYMPUT('EmptyEst',estimate);  RUN;
DATA &CovFewer.; LENGTH Name $30.; SET &CovFewer.; Name="&CovFewer."; RUN;
DATA &CovMore.;  LENGTH Name $30.; SET &CovMore.;  Name="&CovMore.";  RUN;
DATA CovCompare; LENGTH Name $30.; SET &CovBase. &CovFewer. &CovMore.; RUN;
DATA CovCompare; SET CovCompare;  
     R2_from_Base=(&EmptyEst.-Estimate)/&EmptyEst.;
     R2_Increment=R2_from_Base-LAG1(R2_from_Base); 
     IF _N_=2 THEN R2_Increment=.; RUN;
DATA CovCompare; SET CovCompare; 
     IF CovParm IN("UN(2,1)","UN(3,1)","UN(4,1)","UN(3,2)","UN(4,2)","UN(4,3)") 
     THEN DELETE; RUN;
TITLE9 "R2 (% Reduction) Overall and for &CovFewer. vs. &CovMore.";
PROC PRINT NOOBS DATA=CovCompare; RUN; TITLE9;
%MEND ModelR2;

* To use Regions Macro, enter;
*   FixData=    Name of dataset that stores fixed effects for model (SolutionF on ODS);
*   CovBData=   Name of dataset that stores XTX inv matrix for model (CovB on ODS);
*   Pred=       Case-sensitive name of predictor effect regions are for; 
*   Mod=        Case-sensitive name of moderator effect (for region values);
*   ModCenter=  Centering point of moderator predictor;
*   Interact=   Case-sensitive name of interaction effect; 
*   Order=      Order of entry of interaction in MODEL statement;
%MACRO Regions(FixData=,CovBData=, Pred=,Mod=,ModCenter=,Interact=,Order=);
DATA _NULL_; SET &FixData.; WHERE Effect="&Pred.";
     CALL SYMPUT('Bpred', Estimate); 
     CALL SYMPUT('SEpred', StdErr); RUN; 
DATA _NULL_; SET &FixData.; WHERE Effect="&Interact.";
     CALL SYMPUT('Binter', Estimate); 
     CALL SYMPUT('SEinter', StdErr); RUN; 
%LET order=%EVAL(&order.+1);
DATA _NULL_; SET &CovBData.; 
     WHERE INDEX(Effect,"&Pred.")>0 AND INDEX(Effect,"*")=0;
     CALL SYMPUT('CovPredInt', ROUND(Col&order.,.0001)); RUN;    
%PUT Bpred=&Bpred. SEpred=&SEpred. Binter=&Binter. 
     SEinter=&SEinter. CovPredInt=&CovPredInt.;
DATA Regions;  * Intermediate calculations;
     A=(1.96*1.96)*(&SEinter.*&SEinter.)-(&Binter.*&Binter.);
     B=2*((1.96*1.96)*&CovPredInt.-(&Bpred.*&Binter.));
     C=(1.96*1.96*&SEpred.*&SEpred.)-(&Bpred.*&Bpred.);
     CenteredLower=((-1*B)+SQRT((B*B)-4*A*C))/(2*A); 
        CALL SYMPUT('cenlower',ROUND(CenteredLower,.001));
     CenteredUpper=((-1*B)-SQRT((B*B)-4*A*C))/(2*A); 
        CALL SYMPUT('cenupper',ROUND(CenteredUpper,.001));
     UncenteredLower=CenteredLower+&ModCenter.; 
        CALL SYMPUT('uncenlower',ROUND(UncenteredLower,.001));
     UncenteredUpper=CenteredUpper+&ModCenter.; 
        CALL SYMPUT('uncenupper',ROUND(UncenteredUpper,.001));
RUN;
TITLE7 "Regions of significance for &interact. interaction:";
TITLE8 "The effect of &pred. will be significant at centered values of &mod. BELOW the lower bound"; 
TITLE9 "and ABOVE the upper bound, which translate to these uncentered lower and upper bounds."; 
PROC PRINT DATA=Regions NOOBS; VAR CenteredLower--UncenteredUpper; RUN; TITLE7; TITLE8; TITLE9;
%MEND Regions;

***********************************************************************************;
*******             BEGIN DATA MANIPULATION FOR CHAPTER 2 EXAMPLE           *******;
*******                  CHANGE "filesave" to your directory                *******;
***********************************************************************************;

* Defining global variable for file location to be replaced in code below;
%LET filesave= C:\Dropbox\14_SPLH861\861_Example2;
* Location for SAS files for these models (uses macro variable filesave);
LIBNAME filesave "&filesave.";

* Import chapter 2 example data into work library;
DATA work.Chapter2; SET filesave.SAS_Chapter2;
* Center continuous predictors;
age85 = age - 85;
grip9 = grip - 9;
* Creating all possible contrasts for dementia groups;
     IF demgroup=1 THEN DO; demNF=0; demNC=0; END;
ELSE IF demgroup=2 THEN DO; demNF=1; demNC=0; END;
ELSE IF demgroup=3 THEN DO; demNF=0; demNC=1; END;
* Labeling new variables;
LABEL   
age85=  "age85: Age in Years (0=85)"
grip9=  "grip9: Grip Strength in Pounds (0=9)"
demNF=  "demNF: Dementia Contrast for None=0 vs Future=1"
demNC=  "demNC: Dementia Contrast for None=0 vs Current=1";
RUN;

***********************************************************************************;
*******                       BEGIN EXAMPLE 2 MODELS                        *******;
***********************************************************************************;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example2_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 'Eq 2.3: Empty Means Model';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition =  / SOLUTION CL DDFM=BW;
     ODS OUTPUT CovParms=CovEmpty; * Needed to compare with later;
RUN; TITLE1;

TITLE1 'Eq 2.8: Adding Dementia Group';
TITLE2 'Using Manual Group Contrasts so Reference=None';
PROC MIXED DATA=work.Chapter2 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition = age85 grip9 sexMW demNF demNC / CHISQ SOLUTION CL DDFM=BW;
     ODS OUTPUT CovParms=CovDem;
	 CONTRAST "Model R2 F-Test" age85 1, grip9 1, sexmw 1, demNF 1, demNC 1 / CHISQ;
     CONTRAST "Omnibus F-Test for Dementia Group" demNF 1, demNC 1 / CHISQ;
     * Request group means (hold age=85, grip=9, men);
     ESTIMATE "Intercept for None Group"    intercept 1 demNF 0 demNC 0 / CL;
     ESTIMATE "Intercept for Future Group"  intercept 1 demNF 1 demNC 0 / CL;
     ESTIMATE "Intercept for Current Group" intercept 1 demNF 0 demNC 1 / CL;
     * Request group differences;
     ESTIMATE "None   vs. Future Group"   demNF  1 demNC 0 / CL;
     ESTIMATE "None   vs. Current Group"  demNF  0 demNC 1 / CL;
     ESTIMATE "Future vs. Current Group"  demNF -1 demNC 1 / CL;
RUN; TITLE1; TITLE2;
     * Call macro to calculate R2 for overall model;
       %ModelR2(CovBase=CovEmpty, CovFewer=CovSex, CovMore=CovDem);

* Creating 'fake people' to show age*grip interaction;
* Each row is a fake person for which to create a predicted outcome;
DATA work.FakeAgeGrip; INPUT caseID grip9 age85 sexMW demNF demNC; 
DATALINES;
-99  3 -5  0  0  0 
-99  3  0  0  0  0 
-99  3  5  0  0  0 
-99  0 -5  0  0  0 
-99  0  0  0  0  0 
-99  0  5  0  0  0 
-99 -3 -5  0  0  0 
-99 -3  0  0  0  0 
-99 -3  5  0  0  0 
; RUN;
* Merge with real data;
DATA work.PlotAgeGrip; MERGE work.Chapter2 work.FakeAgeGrip; BY caseID; RUN;

TITLE1 'Eq 2.9: Adding Age by Grip Interaction';
TITLE2 'Age 0=85 Grip 0=9';
* Estimate model on data with fake people to make predictions;
PROC MIXED DATA=work.PlotAgeGrip COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition = age85 grip9 sexMW demNF demNC age85*grip9 
                       / CHISQ SOLUTION CL DDFM=BW COVB OUTPM=PredAgeGrip;
     ODS OUTPUT CovParms=CovAgeGrip SolutionF=FixAgeGrip COVB=CovBAgeGrip;
     ESTIMATE 'Future vs Current'                     demNF -1 demNC 1 / CL;
     ESTIMATE 'Age Slope at Grip Strength =  6'       age85 1 age85*grip9 -3 / CL;
     ESTIMATE 'Age Slope at Grip Strength =  9'       age85 1 age85*grip9  0 / CL;
     ESTIMATE 'Age Slope at Grip Strength = 12'       age85 1 age85*grip9  3 / CL;
     ESTIMATE 'Grip Strength Slope at Age = 80'       grip9 1 age85*grip9 -5 / CL;
     ESTIMATE 'Grip Strength Slope at Age = 85'       grip9 1 age85*grip9  0 / CL;
     ESTIMATE 'Grip Strength Slope at Age = 90'       grip9 1 age85*grip9  5 / CL;
     ESTIMATE 'Cognition at Grip = 12 Age = 80'       intercept 1 age85 -5 grip9  3 age85*grip9 -15 / CL;
     ESTIMATE 'Cognition at Grip = 12 Age = 85'       intercept 1 age85  0 grip9  3 age85*grip9   0 / CL;
     ESTIMATE 'Cognition at Grip = 12 Age = 90'       intercept 1 age85  5 grip9  3 age85*grip9  15 / CL;
     ESTIMATE 'Cognition at Grip =  9 Age = 80'       intercept 1 age85 -5 grip9  0 age85*grip9   0 / CL;
     ESTIMATE 'Cognition at Grip =  9 Age = 85'       intercept 1 age85  0 grip9  0 age85*grip9   0 / CL;
     ESTIMATE 'Cognition at Grip =  9 Age = 90'       intercept 1 age85  5 grip9  0 age85*grip9   0 / CL;
     ESTIMATE 'Cognition at Grip =  6 Age = 80'       intercept 1 age85 -5 grip9 -3 age85*grip9  15 / CL;
     ESTIMATE 'Cognition at Grip =  6 Age = 85'       intercept 1 age85  0 grip9 -3 age85*grip9   0 / CL;
     ESTIMATE 'Cognition at Grip =  6 Age = 90'       intercept 1 age85  5 grip9 -3 age85*grip9 -15 / CL;
RUN; TITLE1; TITLE2;
* Call macro for regions of significance for main effects of interaction;
%Regions(FixData=FixAgeGrip, CovBData=CovBAgeGrip, Pred=grip9, Mod=age85,
         ModCenter=85, Interact=age85*grip9, Order=6);
%Regions(FixData=FixAgeGrip, CovBData=CovBAgeGrip, Pred=age85, Mod=grip9,
         ModCenter=9, Interact=age85*grip9, Order=6);
* Call macro to calculate R2 for overall model;
%ModelR2(CovBase=CovEmpty, CovFewer=CovDem, CovMore=CovAgeGrip);
* Subset predicted outcomes data to fake people;
DATA PredAgeGrip; SET PredAgeGrip; WHERE caseID=-99; RUN;
TITLE9 'Predicted Outcomes for Fake People';
PROC PRINT NOOBS DATA=PredAgeGrip; VAR age85 grip9 sexMW demNF demNC pred; RUN;


* Creating 'fake people' to show age*grip*sex interaction;
* Each row is a fake person for which to create a predicted outcome;
DATA work.FakeAgeGripSex; INPUT caseID grip9 age85 sexMW demNF demNC; 
DATALINES;
-99   3  -5  0  0  0 
-99   3   0  0  0  0 
-99   3   5  0  0  0 
-99   0  -5  0  0  0 
-99   0   0  0  0  0 
-99   0   5  0  0  0 
-99  -3  -5  0  0  0 
-99  -3   0  0  0  0 
-99  -3   5  0  0  0 
-99   3  -5  1  0  0 
-99   3   0  1  0  0 
-99   3   5  1  0  0 
-99   0  -5  1  0  0 
-99   0   0  1  0  0 
-99   0   5  1  0  0 
-99  -3  -5  1  0  0 
-99  -3   0  1  0  0 
-99  -3   5  1  0  0 
; RUN;
* Merge with real data;
DATA work.PlotAgeGripSex; MERGE work.Chapter2 work.FakeAgeGripSex; BY caseID; RUN;

TITLE1 'Eq 2.18: Adding Sex by Age by Grip Three-Way Interaction';
TITLE2 'Age 0=85 Grip 0=9 Sex 0=Men Dementia 0=None';
* Estimate model on data with fake people to make predictions;
PROC MIXED DATA=work.PlotAgeGripSex COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
     MODEL cognition = age85 grip9 sexMW demNF demNC age85*grip9 sexMW*demNF sexMW*demNC
                       age85*sexMW grip9*sexMW age85*grip9*sexMW 
						/ CHISQ SOLUTION CL DDFM=BW OUTPM=Pred3AgeSexGrip;
     ODS OUTPUT CovParms=Cov3AgeSexGrip;
* Request simple effects of Age;  
ESTIMATE "Age for Grip=6,  Men"		age85 1 age85*grip9 -3 age85*sexMW  0 age85*grip9*sexMW  0 / CL;
ESTIMATE "Age for Grip=9,  Men"		age85 1 age85*grip9  0 age85*sexMW  0 age85*grip9*sexMW  0 / CL;
ESTIMATE "Age for Grip=12, Men"		age85 1 age85*grip9  3 age85*sexMW  0 age85*grip9*sexMW  0 / CL;
ESTIMATE "Age for Grip=6,  Women"	age85 1 age85*grip9 -3 age85*sexMW  1 age85*grip9*sexMW -3 / CL;
ESTIMATE "Age for Grip=9,  Women"	age85 1 age85*grip9  0 age85*sexMW  1 age85*grip9*sexMW  0 / CL;
ESTIMATE "Age for Grip=12, Women"	age85 1 age85*grip9  3 age85*sexMW  1 age85*grip9*sexMW  3 / CL;
* Request simple effects of Grip; 
ESTIMATE "Grip for Age=80, Men"		grip9 1 age85*grip9 -5 grip9*sexMW  0 age85*grip9*sexMW  0 / CL;
ESTIMATE "Grip for Age=85, Men"		grip9 1 age85*grip9  0 grip9*sexMW  0 age85*grip9*sexMW  0 / CL;
ESTIMATE "Grip for Age=90, Men"		grip9 1 age85*grip9  5 grip9*sexMW  0 age85*grip9*sexMW  0 / CL;
ESTIMATE "Grip for Age=80, Women"	grip9 1 age85*grip9 -5 grip9*sexMW  1 age85*grip9*sexMW -5 / CL;
ESTIMATE "Grip for Age=85, Women"	grip9 1 age85*grip9  0 grip9*sexMW  1 age85*grip9*sexMW  0 / CL;
ESTIMATE "Grip for Age=90, Women"	grip9 1 age85*grip9  5 grip9*sexMW  1 age85*grip9*sexMW  5 / CL;
* Request simple effects of Sex (hold demgroup 0=None); 
ESTIMATE "Sex: Age=80, Grip=6" 		sexMW 1 age85*sexMW -5 grip9*sexMW -3 age85*grip9*sexMW  15 / CL;
ESTIMATE "Sex: Age=85, Grip=6" 		sexMW 1 age85*sexMW  0 grip9*sexMW -3 age85*grip9*sexMW   0 / CL;
ESTIMATE "Sex: Age=90, Grip=6" 		sexMW 1 age85*sexMW  5 grip9*sexMW -3 age85*grip9*sexMW -15 / CL;
ESTIMATE "Sex: Age=80, Grip=9" 		sexMW 1 age85*sexMW -5 grip9*sexMW  0 age85*grip9*sexMW   0 / CL;
ESTIMATE "Sex: Age=85, Grip=9" 		sexMW 1 age85*sexMW  0 grip9*sexMW  0 age85*grip9*sexMW   0 / CL;
ESTIMATE "Sex: Age=90, Grip=9" 		sexMW 1 age85*sexMW  5 grip9*sexMW  0 age85*grip9*sexMW   0 / CL;
ESTIMATE "Sex: Age=80,Grip=12" 		sexMW 1 age85*sexMW -5 grip9*sexMW  3 age85*grip9*sexMW -15 / CL;
ESTIMATE "Sex: Age=85,Grip=12" 		sexMW 1 age85*sexMW  0 grip9*sexMW  3 age85*grip9*sexMW   0 / CL;
ESTIMATE "Sex: Age=90,Grip=12" 		sexMW 1 age85*sexMW  5 grip9*sexMW  3 age85*grip9*sexMW  15 / CL;
* Request simple two-way interactions of age*grip;
ESTIMATE "Age by Grip: Men"		 	age85*grip9 1 age85*grip9*sexMW  0 / CL;
ESTIMATE "Age by Grip: Women"	 	age85*grip9 1 age85*grip9*sexMW  1 / CL;
* Request simple two-way interactions of age*sex;
ESTIMATE "Age by Sex:  Grip=6"	 	age85*sexMW 1 age85*grip9*sexMW -3 / CL;
ESTIMATE "Age by Sex:  Grip=9"	 	age85*sexMW 1 age85*grip9*sexMW  0 / CL;
ESTIMATE "Age by Sex:  Grip=12"	 	age85*sexMW 1 age85*grip9*sexMW  3 / CL;
* Request simple two-way interactions of grip*sex;
ESTIMATE "Grip by Sex: Age=80"	 	grip9*sexMW 1 age85*grip9*sexMW -5 / CL;
ESTIMATE "Grip by Sex: Age=85"	 	grip9*sexMW 1 age85*grip9*sexMW  0 / CL;
ESTIMATE "Grip by Sex: Age=90"	 	grip9*sexMW 1 age85*grip9*sexMW  5 / CL;
RUN; TITLE1; TITLE2;
* Call macro to calculate R2 for overall model;
%ModelR2(CovBase=CovEmpty, CovFewer=Cov2AgeSexGrip, CovMore=Cov3AgeSexGrip);
* Subset predicted outcomes data to fake people;
DATA Pred3AgeSexGrip; SET Pred3AgeSexGrip; WHERE caseID=-99; RUN;
TITLE9 'Predicted Outcomes for Fake People';
PROC PRINT NOOBS DATA=Pred3AgeSexGrip; VAR age85 grip9 sexMW demNF demNC pred; RUN;

* Close output;
ODS RTF CLOSE;
