* Stop syntax and large titles from printing to output.
SET PRINTBACK=NONE HEADER=NO.

***********************************************************************************.
*******            BEGIN DATA MANIPULATION FOR CHAPTER 2 EXAMPLE            *******.
*******                CHANGE "filesave" to your directory                  *******.
***********************************************************************************.

* Define location of files used in code below.
FILE HANDLE filesave /NAME = "C:\Dropbox\14_SPLH861\861_Example2".
* Import chapter 2 example data.
GET FILE = "filesave/SPSS_Chapter2.sav".
DATASET NAME Chapter2 WINDOW=FRONT.
* Center continuous predictors.
COMPUTE age85 = age - 85.
COMPUTE grip9 = grip - 9.
* Creating contrasts for dementia groups.
DO IF (demgroup=1).
COMPUTE demNF=0.
COMPUTE demNC=0.
END IF.
DO IF (demgroup=2).
COMPUTE demNF=1.
COMPUTE demNC=0.
END IF.
DO IF (demgroup=3).
COMPUTE demNF=0.
COMPUTE demNC=1.
END IF.
* Labeling new variables.
VARIABLE LABELS
age85  "age85: Age in Years (0=85)"
grip9  "grip9: Grip Strength in Pounds (0=9)"
demNF  "demNF: Dementia Contrast for None=0 vs Future=1"
demNC  "demNC: Dementia Contrast for None=0 vs Current=1".
EXECUTE.

***********************************************************************************.
*******                       BEGIN EXAMPLE 2 MODELS                        *******.
***********************************************************************************.

* Open output directory.
OUTPUT NAME SPSS_Example2_Output.

DATASET ACTIVATE Chapter2 WINDOW=FRONT.
ECHO 'Eq 2.8: Adding Dementia Group'
      + ', Using Manual Group Contrasts so Reference=None'.
MIXED cognition WITH age85 grip9 sexMW demNF demNC
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = age85 grip9 sexMW demNF demNC
     /TEST     = "Model R2 F-Test" age85 1; grip9 1; sexMW 1; demNF 1; demNC 1
     /TEST     = "Omnibus F-Test for Dementia Group" demNF 1; demNC 1
     /TEST     = "Intercept for None Group"      intercept 1 demNF 0 demNC 0
     /TEST     = "Intercept for Future Group"    intercept 1 demNF 1 demNC 0
     /TEST     = "Intercept for Current Group"   intercept 1 demNF 0 demNC 1
     /TEST     = "None   vs Future  Group"       demNF  1 demNC 0
     /TEST     = "None   vs Current Group"       demNF  0 demNC 1
     /TEST     = "Future vs Current Group"       demNF -1 demNC 1.

* Creating 'fake people' to show age*grip interaction.
* Each row is a fake person for which to create a predicted outcome.
DATA LIST FREE / caseID grip9 age85 sexMW demNF demNC. 
BEGIN DATA.
-99  3 -5  0  0  0 
-99  3  0  0  0  0 
-99  3  5  0  0  0 
-99  0 -5  0  0  0 
-99  0  0  0  0  0 
-99  0  5  0  0  0 
-99 -3 -5  0  0  0 
-99 -3  0  0  0  0 
-99 -3  5  0  0  0 
END DATA.
DATASET NAME FakeAgeGrip.
* Merge with real data.
ADD FILES FILE=Chapter2 /FILE=FakeAgeGrip.
DATASET NAME PlotAgeGrip.
SORT CASES BY caseID.
DATASET CLOSE FakeAgeGrip.

* Estimate model on data with fake people to make predictions.
DATASET ACTIVATE PlotAgeGrip WINDOW=FRONT.
ECHO 'Eq 2.9: Adding Age by Grip Interaction'
      + ', Age 0=85 Grip 0=9'.
MIXED cognition WITH age85 grip9 sexMW demNF demNC
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV COVB
     /FIXED    = age85 grip9 sexMW demNF demNC age85*grip9
     /SAVE     = FIXPRED (PredAgeGrip)
     /TEST     = 'Age Slope at Grip Strength =  6'    age85 1 age85*grip9 -3
     /TEST     = 'Age Slope at Grip Strength =  9'    age85 1 age85*grip9  0
     /TEST     = 'Age Slope at Grip Strength = 12'    age85 1 age85*grip9  3
     /TEST     = 'Grip Strength Slope at Age = 80'    grip9 1 age85*grip9 -5
     /TEST     = 'Grip Strength Slope at Age = 85'    grip9 1 age85*grip9  0
     /TEST     = 'Grip Strength Slope at Age = 90'    grip9 1 age85*grip9  5
     /TEST     = 'Cognition at Grip = 12 Age = 80'    intercept 1 age85 -5 grip9  3 age85*grip9 -15
     /TEST     = 'Cognition at Grip = 12 Age = 85'    intercept 1 age85  0 grip9  3 age85*grip9   0
     /TEST     = 'Cognition at Grip = 12 Age = 90'    intercept 1 age85  5 grip9  3 age85*grip9  15
     /TEST     = 'Cognition at Grip =  9 Age = 80'    intercept 1 age85 -5 grip9  0 age85*grip9   0
     /TEST     = 'Cognition at Grip =  9 Age = 85'    intercept 1 age85  0 grip9  0 age85*grip9   0
     /TEST     = 'Cognition at Grip =  9 Age = 90'    intercept 1 age85  5 grip9  0 age85*grip9   0
     /TEST     = 'Cognition at Grip =  6 Age = 80'    intercept 1 age85 -5 grip9 -3 age85*grip9  15
     /TEST     = 'Cognition at Grip =  6 Age = 85'    intercept 1 age85  0 grip9 -3 age85*grip9   0
     /TEST     = 'Cognition at Grip =  6 Age = 90'    intercept 1 age85  5 grip9 -3 age85*grip9 -15.

* Subset predicted outcomes data to fake people.
DATASET ACTIVATE PlotAgeGrip.
SELECT IF (caseID=-99).
EXECUTE.
ECHO 'Predicted Outcomes for Fake People in PlotAgeGrip Data'.
PRINT TABLE / age85 grip9 sexMW demNF demNC PredAgeGrip.
EXECUTE.

* Creating 'fake people' to show age*grip*sex interaction.
* Each row is a fake person for which to create a predicted outcome.
DATA LIST FREE / caseID grip9 age85 sexMW demNF demNC. 
BEGIN DATA.
-99   3  -5  0  0  0 
-99   3   0  0  0  0 
-99   3   5  0  0  0 
-99   0  -5  0  0  0 
-99   0   0  0  0  0 
-99   0   5  0  0  0 
-99  -3  -5  0  0  0 
-99  -3   0  0  0  0 
-99  -3   5  0  0  0 
-99   3  -5  1  0  0 
-99   3   0  1  0  0 
-99   3   5  1  0  0 
-99   0  -5  1  0  0 
-99   0   0  1  0  0 
-99   0   5  1  0  0 
-99  -3  -5  1  0  0 
-99  -3   0  1  0  0 
-99  -3   5  1  0  0 
END DATA.
DATASET NAME FakeAgeGripSex.
* Merge with real data.
ADD FILES FILE=Chapter2 /FILE=FakeAgeGripSex.
DATASET NAME PlotAgeGripSex.
SORT CASES BY caseID.
DATASET CLOSE FakeAgeGripSex.

* Estimate model on data with fake people to make predictions.
DATASET ACTIVATE PlotAgeGripSex WINDOW=FRONT.
ECHO 'Eq 2.18: Adding Sex by Age by Grip Three-Way Interaction'
      + ', Age 0=85 Grip 0=9 Sex 0=Men Dementia 0=None'.
MIXED cognition WITH age85 grip9 sexMW demNF demNC
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV 
     /FIXED    = age85 grip9 sexMW demNF demNC
                 age85*grip9 sexMW*demNF sexMW*demNC
                 age85*sexMW grip9*sexMW age85*grip9*sexMW
     /SAVE     = FIXPRED (Pred3AgeSexGrip)
/TEST =  "Age for Grip=6,  Men"		   age85 1 age85*grip9 -3 age85*sexMW  0 age85*grip9*sexMW  0 
/TEST =  "Age for Grip=9,  Men"		   age85 1 age85*grip9  0 age85*sexMW  0 age85*grip9*sexMW  0 
/TEST =  "Age for Grip=12, Men"		   age85 1 age85*grip9  3 age85*sexMW  0 age85*grip9*sexMW  0 
/TEST =  "Age for Grip=6,  Women"   age85 1 age85*grip9 -3 age85*sexMW  1 age85*grip9*sexMW -3 
/TEST =  "Age for Grip=9,  Women"	  age85 1 age85*grip9  0 age85*sexMW  1 age85*grip9*sexMW  0 
/TEST =  "Age for Grip=12, Women"	  age85 1 age85*grip9  3 age85*sexMW  1 age85*grip9*sexMW  3 
/TEST =  "Grip for Age=80, Men"		   grip9 1 age85*grip9 -5 grip9*sexMW  0 age85*grip9*sexMW  0 
/TEST =  "Grip for Age=85, Men"		   grip9 1 age85*grip9  0 grip9*sexMW  0 age85*grip9*sexMW  0 
/TEST =  "Grip for Age=90, Men"		   grip9 1 age85*grip9  5 grip9*sexMW  0 age85*grip9*sexMW  0 
/TEST =  "Grip for Age=80, Women"	  grip9 1 age85*grip9 -5 grip9*sexMW  1 age85*grip9*sexMW -5 
/TEST =  "Grip for Age=85, Women"	  grip9 1 age85*grip9  0 grip9*sexMW  1 age85*grip9*sexMW  0 
/TEST =  "Grip for Age=90, Women"	  grip9 1 age85*grip9  5 grip9*sexMW  1 age85*grip9*sexMW  5 
/TEST =  "Sex: Age=80, Grip=6" 		   sexMW 1 age85*sexMW -5 grip9*sexMW -3 age85*grip9*sexMW  15 
/TEST =  "Sex: Age=85, Grip=6" 		   sexMW 1 age85*sexMW  0 grip9*sexMW -3 age85*grip9*sexMW   0 
/TEST =  "Sex: Age=90, Grip=6" 		   sexMW 1 age85*sexMW  5 grip9*sexMW -3 age85*grip9*sexMW -15 
/TEST =  "Sex: Age=80, Grip=9" 		   sexMW 1 age85*sexMW -5 grip9*sexMW  0 age85*grip9*sexMW   0 
/TEST =  "Sex: Age=85, Grip=9" 		   sexMW 1 age85*sexMW  0 grip9*sexMW  0 age85*grip9*sexMW   0 
/TEST =  "Sex: Age=90, Grip=9" 		   sexMW 1 age85*sexMW  5 grip9*sexMW  0 age85*grip9*sexMW   0 
/TEST =  "Sex: Age=80,Grip=12" 		   sexMW 1 age85*sexMW -5 grip9*sexMW  3 age85*grip9*sexMW -15 
/TEST =  "Sex: Age=85,Grip=12" 		   sexMW 1 age85*sexMW  0 grip9*sexMW  3 age85*grip9*sexMW   0 
/TEST =  "Sex: Age=90,Grip=12" 		   sexMW 1 age85*sexMW  5 grip9*sexMW  3 age85*grip9*sexMW  15 
/TEST =  "Age by Grip: Men"		       age85*grip9 1 age85*grip9*sexMW  0 
/TEST =  "Age by Grip: Women"	      age85*grip9 1 age85*grip9*sexMW  1 
/TEST =  "Age by Sex:  Grip=6"	     age85*sexMW 1 age85*grip9*sexMW -3 
/TEST =  "Age by Sex:  Grip=9"	     age85*sexMW 1 age85*grip9*sexMW  0 
/TEST =  "Age by Sex:  Grip=12"	    age85*sexMW 1 age85*grip9*sexMW  3 
/TEST =  "Grip by Sex: Age=80"	     grip9*sexMW 1 age85*grip9*sexMW -5 
/TEST =  "Grip by Sex: Age=85"	     grip9*sexMW 1 age85*grip9*sexMW  0 
/TEST =  "Grip by Sex: Age=90"	     grip9*sexMW 1 age85*grip9*sexMW  5.

* Subset predicted outcomes data to fake people.
DATASET ACTIVATE PlotAgeGripSex.
SELECT IF (caseID=-99).
EXECUTE.
ECHO 'Predicted Outcomes for Fake People in PlotAgeGripSex Data'.
PRINT TABLE / age85 grip9 sexMW demNF demNC Pred3AgeSexGrip.
EXECUTE.


* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=VISIBLE  MODELVIEWS=VISIBLE
  /DOC  DOCUMENTFILE="filesave\SPSS_Example2_Output.doc"
     NOTESCAPTIONS=YES  WIDETABLES=WRAP PAGEBREAKS=YES
     PAGESIZE=INCHES(8.5, 11.0)  TOPMARGIN=INCHES(1.0)  BOTTOMMARGIN=INCHES(1.0)
     LEFTMARGIN=INCHES(1.0)  RIGHTMARGIN=INCHES(1.0).